"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertConfig = void 0;
const error_1 = require("../../error");
function has(obj, k) {
    return obj[k] !== undefined;
}
function extractPattern(type, spec) {
    let glob = "";
    let regex = "";
    if ("source" in spec) {
        glob = spec.source;
    }
    if ("glob" in spec) {
        glob = spec.glob;
    }
    if ("regex" in spec) {
        regex = spec.regex;
    }
    if (glob && regex) {
        throw new error_1.FirebaseError(`Cannot specify a ${type} pattern with both a glob and regex.`);
    }
    else if (glob) {
        return { glob: glob };
    }
    else if (regex) {
        return { regex: regex };
    }
    throw new error_1.FirebaseError(`Cannot specify a ${type} with no pattern (either a glob or regex required).`);
}
function convertConfig(config) {
    if (Array.isArray(config)) {
        throw new error_1.FirebaseError(`convertConfig should be given a single configuration, not an array.`, {
            exit: 2,
        });
    }
    const out = {};
    if (!config) {
        return out;
    }
    if (Array.isArray(config.rewrites)) {
        out.rewrites = config.rewrites.map((rewrite) => {
            const vRewrite = extractPattern("rewrite", rewrite);
            if ("destination" in rewrite) {
                vRewrite.path = rewrite.destination;
            }
            else if ("function" in rewrite) {
                vRewrite.function = rewrite.function;
                if (rewrite.region) {
                    vRewrite.functionRegion = rewrite.region;
                }
                else {
                    vRewrite.functionRegion = "us-central1";
                }
            }
            else if ("dynamicLinks" in rewrite) {
                vRewrite.dynamicLinks = rewrite.dynamicLinks;
            }
            else if ("run" in rewrite) {
                vRewrite.run = Object.assign({ region: "us-central1" }, rewrite.run);
            }
            return vRewrite;
        });
    }
    if (Array.isArray(config.redirects)) {
        out.redirects = config.redirects.map((redirect) => {
            const vRedirect = extractPattern("redirect", redirect);
            vRedirect.location = redirect.destination;
            if (redirect.type) {
                vRedirect.statusCode = redirect.type;
            }
            return vRedirect;
        });
    }
    if (Array.isArray(config.headers)) {
        out.headers = config.headers.map((header) => {
            const vHeader = extractPattern("header", header);
            vHeader.headers = {};
            if (Array.isArray(header.headers) && header.headers.length) {
                header.headers.forEach((h) => {
                    vHeader.headers[h.key] = h.value;
                });
            }
            return vHeader;
        });
    }
    if (has(config, "cleanUrls")) {
        out.cleanUrls = config.cleanUrls;
    }
    if (config.trailingSlash === true) {
        out.trailingSlashBehavior = "ADD";
    }
    else if (config.trailingSlash === false) {
        out.trailingSlashBehavior = "REMOVE";
    }
    if (has(config, "appAssociation")) {
        out.appAssociation = config.appAssociation;
    }
    if (has(config, "i18n")) {
        out.i18n = config.i18n;
    }
    return out;
}
exports.convertConfig = convertConfig;
