"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizeAndValidate = exports.validate = exports.normalize = void 0;
const error_1 = require("../error");
function normalize(config) {
    if (!config) {
        throw new error_1.FirebaseError("No valid functions configuration detected in firebase.json");
    }
    if (Array.isArray(config)) {
        if (config.length < 1) {
            throw new error_1.FirebaseError("Requires at least one functions.source in firebase.json.");
        }
        return config;
    }
    return [config];
}
exports.normalize = normalize;
function validateSingle(config) {
    if (!config.source) {
        throw new error_1.FirebaseError("functions.source must be specified");
    }
    return Object.assign(Object.assign({}, config), { source: config.source });
}
function validate(config) {
    if (config.length > 1) {
        throw new error_1.FirebaseError("More than one functions.source detected in firebase.json.");
    }
    return [validateSingle(config[0])];
}
exports.validate = validate;
function normalizeAndValidate(config) {
    return validate(normalize(config));
}
exports.normalizeAndValidate = normalizeAndValidate;
