import path from "path";
import prettier from "prettier";
import { swaggerVersion } from "./utils";
import v2 from "./v2";
import v3 from "./v3";
export const WARNING_MESSAGE = `/**
* This file was auto-generated by swagger-to-ts.
* Do not make direct changes to the file.
*/


`;
export default function swaggerToTS(schema, options) {
    const version = swaggerVersion(schema);
    let output = `${WARNING_MESSAGE}`;
    switch (version) {
        case 2: {
            output = output.concat(v2(schema, options));
            break;
        }
        case 3: {
            output = output.concat(v3(schema, options));
            break;
        }
    }
    let prettierOptions = { parser: "typescript" };
    if (options && options.prettierConfig) {
        try {
            const userOptions = prettier.resolveConfig.sync(path.resolve(process.cwd(), options.prettierConfig));
            prettierOptions = {
                ...prettierOptions,
                ...userOptions,
            };
        }
        catch (err) {
            console.error(`❌ ${err}`);
        }
    }
    return prettier.format(output, prettierOptions);
}
